@@ -2,9 +2,10 @@ from __future__ import unicode_literals
 
 import os
 
-from mopidy import config, exceptions, ext
+from mopidy import config, ext
+
+__version__ = '0.5.1'
 
-__version__ = '0.1'
 
 class Extension(ext.Extension):
 
@@ -18,14 +19,14 @@ class Extension(ext.Extension):
 
     def get_config_schema(self):
         schema = super(Extension, self).get_config_schema()
+        schema['encoding'] = config.String(choices=('aac', 'mp3'))
+        schema['quality'] = config.String(
+            choices=('highest', 'fast', 'slow', 'firewall'))
         return schema
 
     def validate_environment(self):
-        try:
-            import requests
-        except ImportError as e:
-            raise ExtensionError('Library requests not found', e)
+        pass
 
-    def get_backend_classes(self):
+    def setup(self, registry):
         from .actor import SomaFMBackend
-        return [SomaFMBackend]
+        registry.add('backend', SomaFMBackend)
